@@ -273,9 +273,7 @@ class OpenAIAgent(MCPAgent):
                 if text:
                     text_chunks.append(text)
             elif item.type == "reasoning":
-                reasoning_chunks.append(
-                    "".join(f"Thinking: {summary.text}\n" for summary in item.summary)
-                )
+                reasoning_chunks.append("".join(summary.text for summary in item.summary))
             else:
                 tool_call = self._extract_tool_call(item)
                 if tool_call is not None:
@@ -284,7 +282,9 @@ class OpenAIAgent(MCPAgent):
         if agent_response.tool_calls:
             agent_response.done = False
 
-        agent_response.content = "".join(reasoning_chunks) + "".join(text_chunks)
+        agent_response.content = "".join(text_chunks)
+        if reasoning_chunks:
+            agent_response.reasoning = "\n".join(reasoning_chunks)
         return agent_response
 
     async def format_tool_results(
